==> eleme-openapi-sdk-1.30.85-sources.jar: eleme/openapi/sdk/api/entity/shop/OVideoDeviceDTO.java <==
package eleme.openapi.sdk.api.entity.shop;

import eleme.openapi.sdk.api.enumeration.shop.*;
import eleme.openapi.sdk.api.entity.shop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class OVideoDeviceDTO{

    /**
     * 设备供应商ID
     */
    private String supplyId;
    public String getSupplyId() {
        return supplyId;
    }
    public void setSupplyId(String supplyId) {
        this.supplyId = supplyId;
    }
    
    /**
     * 设备SN码
     */
    private String deviceSn;
    public String getDeviceSn() {
        return deviceSn;
    }
    public void setDeviceSn(String deviceSn) {
        this.deviceSn = deviceSn;
    }
    
    /**
     * 设备当前状态
     */
    private String deviceStatus;
    public String getDeviceStatus() {
        return deviceStatus;
    }
    public void setDeviceStatus(String deviceStatus) {
        this.deviceStatus = deviceStatus;
    }
    
    /**
     * 设备状态变更时间
     */
    private Long statusChangeTime;
    public Long getStatusChangeTime() {
        return statusChangeTime;
    }
    public void setStatusChangeTime(Long statusChangeTime) {
        this.statusChangeTime = statusChangeTime;
    }
    
    /**
     * 设备状态变更原因
     */
    private String deviceStatusChangeReason;
    public String getDeviceStatusChangeReason() {
        return deviceStatusChangeReason;
    }
    public void setDeviceStatusChangeReason(String deviceStatusChangeReason) {
        this.deviceStatusChangeReason = deviceStatusChangeReason;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/shop/OVideoDeviceDTO.java <==
package eleme.openapi.sdk.api.entity.shop;

import eleme.openapi.sdk.api.enumeration.shop.*;
import eleme.openapi.sdk.api.entity.shop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class OVideoDeviceDTO{

    /**
     * 外部通道号
     */
    private String outChannel;
    public String getOutChannel() {
        return outChannel;
    }
    public void setOutChannel(String outChannel) {
        this.outChannel = outChannel;
    }
    
    /**
     * 设备供应商ID
     */
    private String supplyId;
    public String getSupplyId() {
        return supplyId;
    }
    public void setSupplyId(String supplyId) {
        this.supplyId = supplyId;
    }
    
    /**
     * 设备SN码
     */
    private String deviceSn;
    public String getDeviceSn() {
        return deviceSn;
    }
    public void setDeviceSn(String deviceSn) {
        this.deviceSn = deviceSn;
    }
    
    /**
     * 设备当前状态
     */
    private String deviceStatus;
    public String getDeviceStatus() {
        return deviceStatus;
    }
    public void setDeviceStatus(String deviceStatus) {
        this.deviceStatus = deviceStatus;
    }
    
    /**
     * 设备状态变更时间
     */
    private Long statusChangeTime;
    public Long getStatusChangeTime() {
        return statusChangeTime;
    }
    public void setStatusChangeTime(Long statusChangeTime) {
        this.statusChangeTime = statusChangeTime;
    }
    
    /**
     * 设备状态变更原因
     */
    private String deviceStatusChangeReason;
    public String getDeviceStatusChangeReason() {
        return deviceStatusChangeReason;
    }
    public void setDeviceStatusChangeReason(String deviceStatusChangeReason) {
        this.deviceStatusChangeReason = deviceStatusChangeReason;
    }
    
}
